@@ -11,6 +11,7 @@
 /* Please keep this in alphabetical order */
 static gchar *contributors[] = {
 	"J\xc3\xa9r\xc3\xb4me Abela",
+	"Rob Adams",
 	"Lauri Alanko",
 	"Seth Alves",
 	"Shawn T. Amundson",
@@ -106,6 +107,7 @@ static gchar *contributors[] = {
 	"Dave Glowacki",
 	"Scott Goehring",
 	"Randy Gordon",
+	"Ted Gould",
 	"Kenny Graunke",
 	"Jamin Philip Gray",
 	"Dov Grobgeld",
@@ -208,6 +210,7 @@ static gchar *contributors[] = {
 	"Karl Nelson",
 	"Elijah Newren",
 	"Christian Neumair",
+	"Mike Newman",
 	"Asger Alstrup Nielsen",
 	"Seth Nickell",
 	"Eric Nielson",
@@ -232,7 +235,7 @@ static gchar *contributors[] = {
 	"Joe Pfeiffer",
 	"Ben Pierce",
 	"Chris Pinkham",
-	"Hasbullah Bin Pit"
+	"Hasbullah Bin Pit",
 	"Germ\xc3\xa1n Poo-Caama\xc3\xb1o",
 	"Dick Porter",
 	"Tero Pulkkinen",
@@ -255,7 +258,7 @@ static gchar *contributors[] = {
 	"S\xc3\xb8ren Sandmann",
 	"Pablo Saratxaga",
 	/* Kazuhiro Sasayama: */
-	"\xe7\xac\xb9 \xe5\xb1\xb1 \xe5\x92\x82 \xe5\xae\x8f",
+	"\xe7\xac\xb9 \xe5\xb1\xb1 \xe5\x92\x8c \xe5\xae\x8f",
 	"Carsten Schaar",
 	"Christian Schaller",
 	"Wayne Schuller",
@@ -295,6 +298,7 @@ static gchar *contributors[] = {
 	"Kimball Thurston",
 	"Chris Toshok",
 	"Christoph Toshok",
+	"Malcolm Tredinnick",
 	"Tom Tromey",
 	"Jon Trowbridge",
 	"Vincent Untz",
